pub struct FragmentShaderState<'a> {
    pub entry_point: &'a str,
    pub targets: &'a [Option<ColorTargetState>],
}

Fields

entry_point: &'a str

The name of the entry point in the compiled shader. There must be a function that returns void with this name in the shader.

targets: &'a [Option<ColorTargetState>]

The color state of the render targets.