Struct wgpu_biolerless::VertexShaderState
source · [−]pub struct VertexShaderState<'a> {
pub entry_point: &'a str,
pub buffers: &'a [VertexBufferLayout<'a>],
}Fields
entry_point: &'a strThe name of the entry point in the compiled shader. There must be a function that returns void with this name in the shader.
buffers: &'a [VertexBufferLayout<'a>]The format of any vertex buffers used with this pipeline.